@@ -3,7 +3,6 @@ package e2e
 import (
 	"context"
 	"fmt"
-	"strings"
 	"time"
 
 	"github.com/blang/semver"
@@ -11,6 +10,8 @@ import (
 	. "github.com/onsi/gomega"
 	operatorsv1alpha1 "github.com/operator-framework/api/pkg/operators/v1alpha1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/controller/registry"
+	"github.com/operator-framework/operator-lifecycle-manager/test/e2e/ctx"
+
 	"k8s.io/apiextensions-apiserver/pkg/apis/apiextensions"
 	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
 	apiextensionsv1beta1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
@@ -19,7 +20,7 @@ import (
 )
 
 var _ = Describe("CRD Versions", func() {
-	AfterEach(func() { cleaner.NotifyTestComplete(true) }, float64(10))
+	AfterEach(func() { TearDown(testNamespace) }, float64(30))
 
 	It("creates v1beta1 crds with a v1beta1 schema successfully", func() {
 		By("This test proves that OLM is able to handle v1beta1 CRDs successfully. Creating v1 CRDs has more " +
@@ -31,7 +32,6 @@ var _ = Describe("CRD Versions", func() {
 		mainPackageName := genName("nginx-update2-")
 		mainPackageStable := fmt.Sprintf("%s-stable", mainPackageName)
 		stableChannel := "stable"
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
 
 		crdPlural := genName("ins-v1beta1-")
 		crdName := crdPlural + ".cluster.com"
@@ -64,7 +64,7 @@ var _ = Describe("CRD Versions", func() {
 			},
 		}
 
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, mainNamedStrategy)
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{mainCRD}, nil, nil)
 		mainCatalogName := genName("mock-ocs-main-update2-")
 		mainManifests := []registry.PackageManifest{
 			{
@@ -111,7 +111,6 @@ var _ = Describe("CRD Versions", func() {
 		mainPackageName := genName("nginx-update2-")
 		mainPackageStable := fmt.Sprintf("%s-stable", mainPackageName)
 		stableChannel := "stable"
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
 
 		crdPlural := genName("ins-v1beta1-")
 		crdName := crdPlural + ".cluster.com"
@@ -137,7 +136,7 @@ var _ = Describe("CRD Versions", func() {
 			},
 		}
 
-		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, nil, mainNamedStrategy)
+		mainCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), nil, nil, nil)
 		mainCatalogName := genName("mock-ocs-main-update2-")
 		mainManifests := []registry.PackageManifest{
 			{
@@ -185,7 +184,6 @@ var _ = Describe("CRD Versions", func() {
 		mainPackageName := genName("nginx-update2-")
 		mainPackageStable := fmt.Sprintf("%s-stable", mainPackageName)
 		stableChannel := "stable"
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
 
 		crdPlural := genName("ins-v1beta1-")
 		crdName := crdPlural + ".cluster.com"
@@ -258,8 +256,8 @@ var _ = Describe("CRD Versions", func() {
 			},
 		}
 
-		oldCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{oldCRD}, nil, mainNamedStrategy)
-		newCSV := newCSV(mainPackageAlpha, testNamespace, mainPackageStable, semver.MustParse("0.1.1"), []apiextensions.CustomResourceDefinition{newCRD}, nil, mainNamedStrategy)
+		oldCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{oldCRD}, nil, nil)
+		newCSV := newCSV(mainPackageAlpha, testNamespace, mainPackageStable, semver.MustParse("0.1.1"), []apiextensions.CustomResourceDefinition{newCRD}, nil, nil)
 		mainCatalogName := genName("mock-ocs-main-update2-")
 		mainManifests := []registry.PackageManifest{
 			{
@@ -300,34 +298,40 @@ var _ = Describe("CRD Versions", func() {
 
 		// old CRD has been installed onto the cluster - now upgrade the subscription to point to the channel with the new CRD
 		// installing the new CSV should fail with a warning about data loss, since a storage version is missing in the new CRD
-		sub, err := crc.OperatorsV1alpha1().Subscriptions(testNamespace).Get(context.TODO(), subscription.GetName(), metav1.GetOptions{})
-		Expect(err).ToNot(HaveOccurred(), "could not get subscription")
+		// use server-side apply to apply the update to the subscription point to the alpha channel
+		Eventually(Apply(subscription, func(s *operatorsv1alpha1.Subscription) error {
+			s.Spec.Channel = alphaChannel
+			return nil
+		})).Should(Succeed())
+		ctx.Ctx().Logf("updated subscription to point to alpha channel")
 
-		// update channel on sub
-		sub.Spec.Channel = alphaChannel
-		_, err = crc.OperatorsV1alpha1().Subscriptions(testNamespace).Update(context.TODO(), sub, metav1.UpdateOptions{})
-		Expect(err).ToNot(HaveOccurred(), "could not update subscription")
+		subscriptionAtLatestWithDifferentInstallPlan := func(v *operatorsv1alpha1.Subscription) bool {
+			return subscriptionStateAtLatestChecker(v) && v.Status.InstallPlanRef != nil && v.Status.InstallPlanRef.Name != fetchedInstallPlan.Name
+		}
 
 		// fetch new subscription
-		s, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionHasInstallPlanDifferentChecker(installPlanName))
+		s, err := fetchSubscription(crc, testNamespace, subscriptionName, subscriptionAtLatestWithDifferentInstallPlan)
 		Expect(err).ToNot(HaveOccurred())
 		Expect(s).ToNot(BeNil())
 		Expect(s.Status.InstallPlanRef).ToNot(Equal(nil))
 
 		// Check the error on the installplan - should be related to data loss and the CRD upgrade missing a stored version
-		Eventually(func() bool {
-			ip, err := crc.OperatorsV1alpha1().InstallPlans(testNamespace).Get(context.TODO(), s.Status.InstallPlanRef.Name, metav1.GetOptions{})
-			if k8serrors.IsNotFound(err) {
-				return false
-			}
-			if ip.Status.Phase != operatorsv1alpha1.InstallPlanPhaseFailed {
-				return false
-			}
-			if !strings.Contains(ip.Status.Conditions[len(ip.Status.Conditions)-1].Message, "risk of data loss") {
-				return false
-			}
-			return true
-		}, pollDuration, pollInterval).Should(BeTrue())
+		Eventually(func() (*operatorsv1alpha1.InstallPlan, error) {
+			return crc.OperatorsV1alpha1().InstallPlans(testNamespace).Get(context.TODO(), s.Status.InstallPlanRef.Name, metav1.GetOptions{})
+		}).Should(And(
+			WithTransform(
+				func(v *operatorsv1alpha1.InstallPlan) operatorsv1alpha1.InstallPlanPhase {
+					return v.Status.Phase
+				},
+				Equal(operatorsv1alpha1.InstallPlanPhaseFailed),
+			),
+			WithTransform(
+				func(v *operatorsv1alpha1.InstallPlan) string {
+					return v.Status.Conditions[len(v.Status.Conditions)-1].Message
+				},
+				ContainSubstring("risk of data loss"),
+			),
+		))
 	})
 
 	// Create a CRD on cluster with v1alpha1 (storage)
@@ -338,7 +342,7 @@ var _ = Describe("CRD Versions", func() {
 	// Update the CRD status to remove the v1alpha1
 	// Now the installplan should succeed
 
-	It("allows a CRD upgrade that could have caused data loss", func() {
+	It("allows a CRD upgrade that doesn't cause data loss", func() {
 		By("manually editing the storage versions in the existing CRD status")
 
 		c := newKubeClient()
@@ -376,7 +380,9 @@ var _ = Describe("CRD Versions", func() {
 		// wrap CRD update in a poll because of the object has been modified related errors
 		Eventually(func() error {
 			oldCRD, err = c.ApiextensionsInterface().ApiextensionsV1beta1().CustomResourceDefinitions().Get(context.TODO(), oldCRD.GetName(), metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred(), "error getting old CRD")
+			if err != nil {
+				return err
+			}
 			GinkgoT().Logf("old crd status stored versions: %#v", oldCRD.Status.StoredVersions)
 
 			// set v1alpha1 to no longer served
@@ -423,8 +429,7 @@ var _ = Describe("CRD Versions", func() {
 		mainPackageName := genName("nginx-update2-")
 		mainPackageStable := fmt.Sprintf("%s-stable", mainPackageName)
 		stableChannel := "stable"
-		mainNamedStrategy := newNginxInstallStrategy(genName("dep-"), nil, nil)
-		catalogCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{catalogCRD}, nil, mainNamedStrategy)
+		catalogCSV := newCSV(mainPackageStable, testNamespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{catalogCRD}, nil, nil)
 
 		mainCatalogName := genName("mock-ocs-main-update2-")
 		mainManifests := []registry.PackageManifest{
@@ -455,12 +460,12 @@ var _ = Describe("CRD Versions", func() {
 		Expect(catalogCSV.GetName()).To(Equal(subscription.Status.CurrentCSV))
 
 		// Check the error on the installplan - should be related to data loss and the CRD upgrade missing a stored version (v1alpha1)
-		Eventually(func() bool {
-			ip, err := crc.OperatorsV1alpha1().InstallPlans(testNamespace).Get(context.TODO(), subscription.Status.InstallPlanRef.Name, metav1.GetOptions{})
-			Expect(err).ToNot(HaveOccurred(), "could not get installplan")
-
-			return ip.Status.Phase == operatorsv1alpha1.InstallPlanPhaseFailed
-		}).Should(BeTrue())
+		Eventually(func() (*operatorsv1alpha1.InstallPlan, error) {
+			return crc.OperatorsV1alpha1().InstallPlans(testNamespace).Get(context.TODO(), subscription.Status.InstallPlanRef.Name, metav1.GetOptions{})
+		}).Should(WithTransform(
+			func(v *operatorsv1alpha1.InstallPlan) operatorsv1alpha1.InstallPlanPhase { return v.Status.Phase },
+			Equal(operatorsv1alpha1.InstallPlanPhaseFailed),
+		))
 
 		// update CRD status to remove the v1alpha1 stored version
 		newCRD, err := c.ApiextensionsInterface().ApiextensionsV1beta1().CustomResourceDefinitions().Get(context.TODO(), oldCRD.GetName(), metav1.GetOptions{})
@@ -471,15 +476,18 @@ var _ = Describe("CRD Versions", func() {
 		GinkgoT().Logf("new crd status stored versions: %#v", newCRD.Status.StoredVersions) // only v1alpha2 should be in the status now
 
 		// install should now succeed
-		// first remove old install plan
 		oldInstallPlanRef := subscription.Status.InstallPlanRef.Name
 		err = crc.OperatorsV1alpha1().InstallPlans(testNamespace).Delete(context.TODO(), subscription.Status.InstallPlanRef.Name, metav1.DeleteOptions{})
 		Expect(err).ToNot(HaveOccurred(), "error deleting failed install plan")
-		//remove old subscription
+		// remove old subscription
 		err = crc.OperatorsV1alpha1().Subscriptions(testNamespace).Delete(context.TODO(), subscription.GetName(), metav1.DeleteOptions{})
-		Expect(err).ToNot(HaveOccurred(), "error deleting failed install plan")
+		Expect(err).ToNot(HaveOccurred(), "error deleting old subscription")
+		// remove old csv
+		crc.OperatorsV1alpha1().ClusterServiceVersions(testNamespace).Delete(context.TODO(), mainPackageStable, metav1.DeleteOptions{})
+		Expect(err).ToNot(HaveOccurred(), "error deleting old subscription")
 
-		//recreate subscription
+
+		// recreate subscription
 		subscriptionNameNew := genName("sub-nginx-update2-new-")
 		_ = createSubscriptionForCatalog(crc, testNamespace, subscriptionNameNew, mainCatalogName, mainPackageName, stableChannel, "", operatorsv1alpha1.ApprovalAutomatic)
 
