@@ -35,7 +35,7 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 	})
 
 	AfterEach(func() {
-		cleaner.NotifyTestComplete(true)
+		TearDown(testNamespace)
 	})
 
 	Context("Given a ClusterRole owned by a CustomResourceDefinition", func() {
@@ -196,8 +196,8 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 
 		BeforeEach(func() {
 
-			ownerA = newCSV("ownera", testNamespace, "", semver.MustParse("0.0.0"), nil, nil, newNginxInstallStrategy("dep-", nil, nil))
-			ownerB = newCSV("ownerb", testNamespace, "", semver.MustParse("0.0.0"), nil, nil, newNginxInstallStrategy("dep-", nil, nil))
+			ownerA = newCSV("ownera", testNamespace, "", semver.MustParse("0.0.0"), nil, nil, nil)
+			ownerB = newCSV("ownerb", testNamespace, "", semver.MustParse("0.0.0"), nil, nil, nil)
 
 			// create all owners
 			var err error
@@ -298,6 +298,8 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				sourceName = "test-catalog"
 				imageName  = "quay.io/olmtest/single-bundle-index:objects"
 			)
+			var installPlanRef string
+
 			// create catalog source
 			source := &v1alpha1.CatalogSource{
 				TypeMeta: metav1.TypeMeta{
@@ -315,17 +317,30 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				},
 			}
 
-			source, err := operatorClient.OperatorsV1alpha1().CatalogSources(source.GetNamespace()).Create(context.TODO(), source, metav1.CreateOptions{})
-			Expect(err).ToNot(HaveOccurred(), "could not create catalog source")
+			Eventually(func() error {
+				cs, err := operatorClient.OperatorsV1alpha1().CatalogSources(source.GetNamespace()).Create(context.TODO(), source, metav1.CreateOptions{})
+				if err != nil {
+					return err
+				}
+				source = cs.DeepCopy()
+
+				return nil
+			}).Should(Succeed(), "could not create catalog source")
 
 			// Create a Subscription for package
 			_ = createSubscriptionForCatalog(operatorClient, source.GetNamespace(), subName, source.GetName(), packageName, channelName, "", v1alpha1.ApprovalAutomatic)
 
 			// Wait for the Subscription to succeed
-			Eventually(func() error {
-				_, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
-				return err
-			}).Should(BeNil())
+			sub, err := fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
+			Expect(err).ToNot(HaveOccurred(), "could not get subscription at latest status")
+
+			installPlanRef = sub.Status.InstallPlanRef.Name
+
+			// Wait for the installplan to complete (5 minute timeout)
+			_, err = fetchInstallPlan(GinkgoT(), operatorClient, installPlanRef, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+			Expect(err).ToNot(HaveOccurred(), "could not get installplan at complete phase")
+
+			ctx.Ctx().Logf("install plan %s completed", installPlanRef)
 
 			// confirm extra bundle objects (secret and configmap) are installed
 			Eventually(func() error {
@@ -393,6 +408,8 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				sourceName  = "test-catalog"
 				imageName   = "quay.io/olmtest/single-bundle-index:objects-upgrade-samename"
 			)
+
+			var installPlanRef string
 			// create catalog source
 			source := &v1alpha1.CatalogSource{
 				TypeMeta: metav1.TypeMeta{
@@ -417,10 +434,14 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 			_ = createSubscriptionForCatalog(operatorClient, source.GetNamespace(), subName, source.GetName(), packageName, channelName, "", v1alpha1.ApprovalAutomatic)
 
 			// Wait for the Subscription to succeed
-			Eventually(func() error {
-				_, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
-				return err
-			}).Should(BeNil())
+			sub, err := fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
+			Expect(err).ToNot(HaveOccurred(), "could not get subscription at latest status")
+
+			installPlanRef = sub.Status.InstallPlanRef.Name
+
+			// Wait for the installplan to complete (5 minute timeout)
+			_, err = fetchInstallPlan(GinkgoT(), operatorClient, installPlanRef, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+			Expect(err).ToNot(HaveOccurred(), "could not get installplan at complete phase")
 
 			Eventually(func() error {
 				_, err := kubeClient.GetConfigMap(testNamespace, configmapName)
@@ -433,6 +454,7 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				upgradeChannelName = "beta"
 				newCSVname         = "busybox.v3.0.0"
 			)
+			var installPlanRef string
 
 			BeforeEach(func() {
 				// update subscription first
@@ -445,10 +467,14 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				Expect(err).ToNot(HaveOccurred(), "could not update subscription")
 
 				// Wait for the Subscription to succeed
-				Eventually(func() error {
-					_, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
-					return err
-				}).Should(BeNil())
+				sub, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
+				Expect(err).ToNot(HaveOccurred(), "could not get subscription at latest status")
+
+				installPlanRef = sub.Status.InstallPlanRef.Name
+
+				// Wait for the installplan to complete (5 minute timeout)
+				_, err = fetchInstallPlan(GinkgoT(), operatorClient, installPlanRef, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+				Expect(err).ToNot(HaveOccurred(), "could not get installplan at complete phase")
 
 				// Ensure the new csv is installed
 				Eventually(func() error {
@@ -458,16 +484,15 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 			})
 
 			It("OLM should have upgraded associated configmap in place", func() {
-				Eventually(func() bool {
+				Eventually(func() (string, error) {
 					cfg, err := kubeClient.GetConfigMap(testNamespace, configmapName)
 					if err != nil {
-						return false
+						return "", err
 					}
 					// check data in configmap to ensure it is the new data (configmap was updated in the newer bundle)
 					// new value in the configmap is "updated-very-much"
-					data := cfg.Data["special.how"]
-					return data == "updated-very-much"
-				}).Should(BeTrue())
+					return cfg.Data["special.how"], nil
+				}).Should(Equal("updated-very-much"))
 				ctx.Ctx().Logf("dependent successfully updated after csv owner was updated")
 			})
 		})
@@ -486,6 +511,8 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				sourceName  = "test-catalog"
 				imageName   = "quay.io/olmtest/single-bundle-index:objects-upgrade-diffname"
 			)
+
+			var installPlanRef string
 			// create catalog source
 			source := &v1alpha1.CatalogSource{
 				TypeMeta: metav1.TypeMeta{
@@ -510,10 +537,14 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 			_ = createSubscriptionForCatalog(operatorClient, source.GetNamespace(), subName, source.GetName(), packageName, channelName, "", v1alpha1.ApprovalAutomatic)
 
 			// Wait for the Subscription to succeed
-			Eventually(func() error {
-				_, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
-				return err
-			}).Should(BeNil())
+			sub, err := fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
+			Expect(err).ToNot(HaveOccurred(), "could not get subscription at latest status")
+
+			installPlanRef = sub.Status.InstallPlanRef.Name
+
+			// Wait for the installplan to complete (5 minute timeout)
+			_, err = fetchInstallPlan(GinkgoT(), operatorClient, installPlanRef, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+			Expect(err).ToNot(HaveOccurred(), "could not get installplan at complete phase")
 
 			Eventually(func() error {
 				_, err := kubeClient.GetConfigMap(testNamespace, configmapName)
@@ -527,6 +558,7 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				upgradedConfigMapName = "not-special-config"
 				newCSVname            = "busybox.v3.0.0"
 			)
+			var installPlanRef string
 
 			BeforeEach(func() {
 				// update subscription first
@@ -539,10 +571,14 @@ var _ = Describe("Garbage collection for dependent resources", func() {
 				Expect(err).ToNot(HaveOccurred(), "could not update subscription")
 
 				// Wait for the Subscription to succeed
-				Eventually(func() error {
-					_, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
-					return err
-				}).Should(BeNil())
+				sub, err = fetchSubscription(operatorClient, testNamespace, subName, subscriptionStateAtLatestChecker)
+				Expect(err).ToNot(HaveOccurred(), "could not get subscription at latest status")
+
+				installPlanRef = sub.Status.InstallPlanRef.Name
+
+				// Wait for the installplan to complete (5 minute timeout)
+				_, err = fetchInstallPlan(GinkgoT(), operatorClient, installPlanRef, buildInstallPlanPhaseCheckFunc(v1alpha1.InstallPlanPhaseComplete))
+				Expect(err).ToNot(HaveOccurred(), "could not get installplan at complete phase")
 
 				// Ensure the new csv is installed
 				Eventually(func() error {
