@@ -6,6 +6,7 @@ import (
 
 	"github.com/blang/semver"
 	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/gomega"
 	v1 "github.com/operator-framework/api/pkg/operators/v1"
 	"github.com/operator-framework/api/pkg/operators/v1alpha1"
 	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/client/clientset/versioned"
@@ -17,19 +18,22 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	"k8s.io/apiextensions-apiserver/pkg/apis/apiextensions"
+	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
 var _ = Describe("User defined service account", func() {
-	It("with no permission", func() {
+	AfterEach(func() {
+		TearDown(testNamespace)
+	})
 
-		defer cleaner.NotifyTestComplete(false)
+	It("with no permission", func() {
 
 		kubeclient := newKubeClient()
 		crclient := newCRClient()
 
 		namespace := genName("scoped-ns-")
-		_, cleanupNS := newNamespace(GinkgoT(), kubeclient, namespace)
+		_, cleanupNS := newNamespace(kubeclient, namespace)
 		defer cleanupNS()
 
 		// Create a service account, but add no permission to it.
@@ -77,14 +81,12 @@ var _ = Describe("User defined service account", func() {
 	})
 	It("with permission", func() {
 
-		defer cleaner.NotifyTestComplete(false)
-
 		// Create the CatalogSource
 		kubeclient := newKubeClient()
 		crclient := newCRClient()
 
 		namespace := genName("scoped-ns-")
-		_, cleanupNS := newNamespace(GinkgoT(), kubeclient, namespace)
+		_, cleanupNS := newNamespace(kubeclient, namespace)
 		defer cleanupNS()
 
 		// Create a service account, add enough permission to it so that operator install is successful.
@@ -129,18 +131,18 @@ var _ = Describe("User defined service account", func() {
 
 		// Verify that all step resources are in Created state.
 		for _, step := range ipGot.Status.Plan {
-			assert.Equal(GinkgoT(), v1alpha1.StepStatusCreated, step.Status)
+			// TODO: switch back to commented assertion once InstallPlan status is being patched instead of updated
+			// assert.Equal(GinkgoT(), v1alpha1.StepStatusCreated, step.Status)
+			Expect(step.Status).To(Or(Equal(v1alpha1.StepStatusCreated), Equal(v1alpha1.StepStatusPresent)))
 		}
 	})
 	It("with retry", func() {
 
-		defer cleaner.NotifyTestComplete(false)
-
 		kubeclient := newKubeClient()
 		crclient := newCRClient()
 
 		namespace := genName("scoped-ns-")
-		_, cleanupNS := newNamespace(GinkgoT(), kubeclient, namespace)
+		_, cleanupNS := newNamespace(kubeclient, namespace)
 		defer cleanupNS()
 
 		// Create a service account, but add no permission to it.
@@ -188,20 +190,27 @@ var _ = Describe("User defined service account", func() {
 	})
 })
 
-func newNamespace(t GinkgoTInterface, client operatorclient.ClientInterface, name string) (ns *corev1.Namespace, cleanup cleanupFunc) {
+func newNamespace(client operatorclient.ClientInterface, name string) (ns *corev1.Namespace, cleanup cleanupFunc) {
 	request := &corev1.Namespace{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: name,
 		},
 	}
 
-	ns, err := client.KubernetesInterface().CoreV1().Namespaces().Create(context.TODO(), request, metav1.CreateOptions{})
-	require.NoError(t, err)
-	require.NotNil(t, ns)
+	Eventually(func() (err error) {
+		ns, err = client.KubernetesInterface().CoreV1().Namespaces().Create(context.TODO(), request, metav1.CreateOptions{})
+		return
+	}).Should(Succeed())
 
 	cleanup = func() {
-		err := client.KubernetesInterface().CoreV1().Namespaces().Delete(context.TODO(), ns.GetName(), metav1.DeleteOptions{})
-		require.NoError(t, err)
+		Eventually(func() error {
+			err := client.KubernetesInterface().CoreV1().Namespaces().Delete(context.TODO(), ns.GetName(), metav1.DeleteOptions{})
+			if apierrors.IsNotFound(err) {
+				err = nil
+			}
+
+			return err
+		}).Should(Succeed())
 	}
 
 	return
@@ -283,8 +292,8 @@ func newCatalogSource(t GinkgoTInterface, kubeclient operatorclient.ClientInterf
 	stableChannel := "stable"
 
 	namedStrategy := newNginxInstallStrategy(genName(prefixFunc("dep")), permissions, nil)
-	csvA := newCSV("nginx-a", namespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
-	csvB := newCSV("nginx-b", namespace, "nginx-a", semver.MustParse("0.2.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
+	csvA := newCSV("nginx-a", namespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, &namedStrategy)
+	csvB := newCSV("nginx-b", namespace, "nginx-a", semver.MustParse("0.2.0"), []apiextensions.CustomResourceDefinition{crd}, nil, &namedStrategy)
 
 	// Create PackageManifests
 	manifests := []registry.PackageManifest{
@@ -344,8 +353,8 @@ func newCatalogSourceWithDependencies(t GinkgoTInterface, kubeclient operatorcli
 	stableChannel := "stable"
 
 	namedStrategy := newNginxInstallStrategy(genName(prefixFunc("dep")), permissions, nil)
-	csvA := newCSV("nginx-req-dep", namespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{crd}, namedStrategy)
-	csvB := newCSV("nginx-dependency", namespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, namedStrategy)
+	csvA := newCSV("nginx-req-dep", namespace, "", semver.MustParse("0.1.0"), nil, []apiextensions.CustomResourceDefinition{crd}, &namedStrategy)
+	csvB := newCSV("nginx-dependency", namespace, "", semver.MustParse("0.1.0"), []apiextensions.CustomResourceDefinition{crd}, nil, &namedStrategy)
 
 	// Create PackageManifests
 	manifests := []registry.PackageManifest{
